/**
 * =========================================
 * LibFormula : a free Java formula library
 * =========================================
 *
 * Project Info:  http://reporting.pentaho.org/libformula/
 *
 * (C) Copyright 2006-2008, by Pentaho Corporation and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 *
 *
 * ------------
 * Function.java
 * ------------
 */
package org.pentaho.reporting.libraries.formula.function;

import java.io.Serializable;

import org.pentaho.reporting.libraries.formula.lvalues.TypeValuePair;
import org.pentaho.reporting.libraries.formula.FormulaContext;
import org.pentaho.reporting.libraries.formula.EvaluationException;
import org.pentaho.reporting.libraries.formula.typing.TypeConversionException;

/**
 * A function is an arbitary computation. A return value type is not available
 * unless the function has been evaluated.
 *
 * Functions must be stateless, that means: Calling the same function with
 * exactly the same parameters must always result in the same computed value.
 *
 * @author Thomas Morgner
 */
public interface Function extends Serializable
{
  public String getCanonicalName();
  public TypeValuePair evaluate (FormulaContext context,
                                 ParameterCallback parameters)
      throws EvaluationException;
}
